Struct sc_network::config::AlwaysBadChecker [−][src]
Dummy implementation of FetchChecker that always assumes that responses are bad.
Considering that it is the responsibility of the client to build the fetcher, it can use this implementation if it knows that it will never perform any request.