Enum sc_network::Event [−][src]
pub enum Event {
Dht(DhtEvent),
SyncConnected {
remote: PeerId,
},
SyncDisconnected {
remote: PeerId,
},
NotificationStreamOpened {
remote: PeerId,
protocol: Cow<'static, str>,
negotiated_fallback: Option<Cow<'static, str>>,
role: ObservedRole,
},
NotificationStreamClosed {
remote: PeerId,
protocol: Cow<'static, str>,
},
NotificationsReceived {
remote: PeerId,
messages: Vec<(Cow<'static, str>, Bytes)>,
},
}Expand description
Type for events generated by networking layer.
Variants
Dht(DhtEvent)Event generated by a DHT.
Tuple Fields of Dht
0: DhtEventNow connected to a new peer for syncing purposes.
Fields of SyncConnected
remote: PeerIdNode we are now syncing from.
Now disconnected from a peer for syncing purposes.
Fields of SyncDisconnected
remote: PeerIdNode we are no longer syncing from.
Opened a substream with the given node with the given notifications protocol.
The protocol is always one of the notification protocols that have been registered.
Fields of NotificationStreamOpened
remote: PeerIdNode we opened the substream with.
protocol: Cow<'static, str>The concerned protocol. Each protocol uses a different substream.
This is always equal to the value of
crate::config::NonDefaultSetConfig::notifications_protocol of one of the
configured sets.
negotiated_fallback: Option<Cow<'static, str>>If the negotiation didn’t use the main name of the protocol (the one in
notifications_protocol), then this field contains which name has actually been
used.
Always contains a value equal to the value in
crate::config::NonDefaultSetConfig::fallback_names.
role: ObservedRoleRole of the remote.
Closed a substream with the given node. Always matches a corresponding previous
NotificationStreamOpened message.
Fields of NotificationStreamClosed
Received one or more messages from the given node using the given protocol.
Fields of NotificationsReceived