Module event

Module event 

Network event types. These are not the part of the protocol, but rather events that happen on the network like DHT get/put results received.

Enums

DhtEvent
Events generated by DHT as a response to get_value and put_value requests.
Event
Type for events generated by networking layer.