[]Enum sc_network::multiaddr::multihash::Hash

pub enum Hash {
    Identity,
    SHA1,
    SHA2256,
    SHA2512,
    SHA3512,
    SHA3384,
    SHA3256,
    SHA3224,
    Keccak224,
    Keccak256,
    Keccak384,
    Keccak512,
    Blake2b512,
    Blake2b256,
    Blake2s256,
    Blake2s128,
}

List of types currently supported in the multihash spec.

Not all hash types are supported by this library.

Variants

Identity

Identity (Raw binary )

SHA1

SHA-1 (20-byte hash size)

SHA2256

SHA-256 (32-byte hash size)

SHA2512

SHA-512 (64-byte hash size)

SHA3512

SHA3-512 (64-byte hash size)

SHA3384

SHA3-384 (48-byte hash size)

SHA3256

SHA3-256 (32-byte hash size)

SHA3224

SHA3-224 (28-byte hash size)

Keccak224

Keccak-224 (28-byte hash size)

Keccak256

Keccak-256 (32-byte hash size)

Keccak384

Keccak-384 (48-byte hash size)

Keccak512

Keccak-512 (64-byte hash size)

Blake2b512

BLAKE2b-512 (64-byte hash size)

Blake2b256

BLAKE2b-256 (32-byte hash size)

Blake2s256

BLAKE2s-256 (32-byte hash size)

Blake2s128

BLAKE2s-128 (16-byte hash size)

Methods

impl Hash

pub fn code(&self) -> u16

Get the corresponding hash code.

pub fn size(&self) -> u8

Get the hash length in bytes.

pub fn from_code(code: u16) -> Option<Hash>

Returns the algorithm corresponding to a code, or None if no algorithm is matching.