Struct sc_network::multiaddr::multihash::MultihashGeneric [−][src]
pub struct MultihashGeneric<S> where
S: Size, { /* fields omitted */ }Expand description
A Multihash instance that only supports the basic functionality and no hashing.
With this Multihash implementation you can operate on Multihashes in a generic way, but no hasher implementation is associated with the code.
Example
use multihash::Multihash;
const Sha3_256: u64 = 0x16;
let digest_bytes = [
0x16, 0x20, 0x64, 0x4b, 0xcc, 0x7e, 0x56, 0x43, 0x73, 0x04, 0x09, 0x99, 0xaa, 0xc8, 0x9e,
0x76, 0x22, 0xf3, 0xca, 0x71, 0xfb, 0xa1, 0xd9, 0x72, 0xfd, 0x94, 0xa3, 0x1c, 0x3b, 0xfb,
0xf2, 0x4e, 0x39, 0x38,
];
let mh = Multihash::from_bytes(&digest_bytes).unwrap();
assert_eq!(mh.code(), Sha3_256);
assert_eq!(mh.size(), 32);
assert_eq!(mh.digest(), &digest_bytes[2..]);Implementations
Wraps the digest in a multihash.
Reads a multihash from a byte stream.
Parses a multihash from a bytes.
You need to make sure the passed in bytes have the correct length. The digest length
needs to match the size value of the multihash.
Writes a multihash to a byte stream.