PeerId

Struct PeerId 

pub struct PeerId { /* private fields */ }
Identifier of a peer of the network.

The data is a CIDv0 compatible multihash of the protobuf encoded public key of the peer as specified in specs/peer-ids.

Implementations

Source

impl PeerId

pub fn random() -> PeerId

Generate random peer ID.

pub fn try_from_multiaddr(address: &Multiaddr) -> Option<PeerId>

Try to extract PeerId from Multiaddr.

pub fn from_multihash(multihash: Multihash) -> Result<PeerId, Multihash>

Tries to turn a Multihash into a PeerId.

If the multihash does not use a valid hashing algorithm for peer IDs, or the hash value does not satisfy the constraints for a hashed peer ID, it is returned as an Err.

pub fn from_bytes(data: &[u8]) -> Result<PeerId, Error>

Parses a PeerId from bytes.

pub fn to_bytes(&self) -> Vec<u8>

Returns a raw bytes representation of this PeerId.

pub fn to_base58(&self) -> String

Returns a base-58 encoded string of this PeerId.

pub fn into_ed25519(&self) -> Option<[u8; 32]>

Convert PeerId into ed25519 public key bytes.

pub fn from_ed25519(bytes: &[u8; 32]) -> Option<PeerId>

Get PeerId from ed25519 public key bytes.