[−]Enum sc_network::multiaddr::multihash::Hash
List of types currently supported in the multihash spec.
Not all hash types are supported by this library.
Variants
Identity (Raw binary )
SHA-1 (20-byte hash size)
SHA-256 (32-byte hash size)
SHA-512 (64-byte hash size)
SHA3-512 (64-byte hash size)
SHA3-384 (48-byte hash size)
SHA3-256 (32-byte hash size)
SHA3-224 (28-byte hash size)
Keccak-224 (28-byte hash size)
Keccak-256 (32-byte hash size)
Keccak-384 (48-byte hash size)
Keccak-512 (64-byte hash size)
BLAKE2b-512 (64-byte hash size)
BLAKE2b-256 (32-byte hash size)
BLAKE2s-256 (32-byte hash size)
BLAKE2s-128 (16-byte hash size)
Methods
impl Hash
pub fn code(&self) -> u16
Get the corresponding hash code.
pub fn size(&self) -> u8
Get the hash length in bytes.
pub fn from_code(code: u16) -> Option<Hash>
Returns the algorithm corresponding to a code, or None if no algorithm is matching.